@@ -25,61 +25,63 @@ impl Info {
      * See
      * [PQconninfoParse](https://www.postgresql.org/docs/current/libpq-connect.html#LIBPQ-PQCONNINFOPARSE).
      */
-    pub fn from(dsn: &str) -> std::result::Result<Vec<Self>, String> {
+    pub fn from(dsn: &str) -> crate::errors::Result<Vec<Self>> {
         let c_dsn = crate::ffi::to_cstr(dsn);
 
         unsafe {
-            let mut errmsg: *mut i8 = std::ptr::null_mut();
+            let mut errmsg: *mut libc::c_char = std::ptr::null_mut();
             let raw = pq_sys::PQconninfoParse(c_dsn.as_ptr(), &mut errmsg);
 
             if raw.is_null() {
                 if errmsg.is_null() {
-                    return Err("Unknow error".to_string());
+                    return Err(crate::errors::Error::Unknow);
                 } else {
-                    let err = crate::ffi::to_string(errmsg);
+                    let err = crate::ffi::to_string(errmsg)?;
                     pq_sys::PQfreemem(errmsg as *mut std::ffi::c_void);
-                    return Err(err);
+                    return Err(crate::errors::Error::Backend(err));
                 }
             }
 
             let info = Self::vec_from_nta(raw);
             pq_sys::PQconninfoFree(raw);
 
-            Ok(info)
+            info
         }
     }
 
-    fn from_raw(info: *mut pq_sys::_PQconninfoOption) -> Self {
-        unsafe {
+    fn from_raw(raw: *mut pq_sys::_PQconninfoOption) -> crate::errors::Result<Self> {
+        let info = unsafe {
             Self {
-                keyword: crate::ffi::to_string((*info).keyword),
-                envvar: if (*info).envvar.is_null() {
+                keyword: crate::ffi::to_string((*raw).keyword)?,
+                envvar: if (*raw).envvar.is_null() {
                     None
                 } else {
-                    Some(crate::ffi::to_string((*info).envvar))
+                    Some(crate::ffi::to_string((*raw).envvar)?)
                 },
-                compiled: if (*info).compiled.is_null() {
+                compiled: if (*raw).compiled.is_null() {
                     None
                 } else {
-                    Some(crate::ffi::to_string((*info).compiled))
+                    Some(crate::ffi::to_string((*raw).compiled)?)
                 },
-                val: if (*info).val.is_null() {
+                val: if (*raw).val.is_null() {
                     None
                 } else {
-                    Some(crate::ffi::to_string((*info).val))
+                    Some(crate::ffi::to_string((*raw).val)?)
                 },
-                label: if (*info).label.is_null() {
+                label: if (*raw).label.is_null() {
                     None
                 } else {
-                    Some(crate::ffi::to_string((*info).label))
+                    Some(crate::ffi::to_string((*raw).label)?)
                 },
-                dispchar: crate::ffi::to_string((*info).dispchar),
-                dispsize: (*info).dispsize,
+                dispchar: crate::ffi::to_string((*raw).dispchar)?,
+                dispsize: (*raw).dispsize,
             }
-        }
+        };
+
+        Ok(info)
     }
 
-    fn vec_from_nta(raw: *mut pq_sys::_PQconninfoOption) -> Vec<Self> {
+    fn vec_from_nta(raw: *mut pq_sys::_PQconninfoOption) -> crate::errors::Result<Vec<Self>> {
         let mut vec = Vec::new();
 
         for x in 0.. {
@@ -87,13 +89,13 @@ impl Info {
                 if (*raw.offset(x)).keyword.is_null() {
                     break;
                 } else {
-                    let info = raw.offset(x).into();
+                    let info = raw.offset(x).try_into()?;
                     vec.push(info);
                 }
             }
         }
 
-        vec
+        Ok(vec)
     }
 }
 
@@ -101,7 +103,7 @@ impl Default for Info {
     fn default() -> Self {
         unsafe {
             let raw = pq_sys::PQconndefaults();
-            let info = raw.into();
+            let info = raw.try_into().unwrap();
             pq_sys::PQconninfoFree(raw);
 
             info
@@ -110,8 +112,10 @@ impl Default for Info {
 }
 
 #[doc(hidden)]
-impl From<*mut pq_sys::_PQconninfoOption> for Info {
-    fn from(info: *mut pq_sys::_PQconninfoOption) -> Self {
+impl TryFrom<*mut pq_sys::_PQconninfoOption> for Info {
+    type Error = crate::errors::Error;
+
+    fn try_from(info: *mut pq_sys::_PQconninfoOption) -> Result<Self, Self::Error> {
         Self::from_raw(info)
     }
 }
@@ -123,7 +127,9 @@ mod test {
         assert!(crate::connection::Info::from("host=localhost user=postgres").is_ok());
         assert_eq!(
             crate::connection::Info::from("'"),
-            Err("missing \"=\" after \"'\" in connection info string\n".to_string())
+            Err(crate::errors::Error::Backend(
+                "missing \"=\" after \"'\" in connection info string\n".to_string()
+            ))
         );
     }
 
